@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub;
 {
-  $Dist::Zilla::Plugin::GitHub::VERSION = '0.28';
+  $Dist::Zilla::Plugin::GitHub::VERSION = '0.29';
 }
 
 use strict;
@@ -29,12 +29,12 @@ Dist::Zilla::Plugin::GitHub - Plugins to integrate Dist::Zilla with GitHub
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 DESCRIPTION
 
-B<Dist::Zilla::Plugin::GitHub> ships a bunch of L<Dist::Zilla> plugins, aimed at
-easing the maintainance of Dist::Zilla-managed modules with L<GitHub|https://github.com>.
+B<Dist::Zilla::Plugin::GitHub> is a set of plugins for L<Dist::Zilla> intended
+to more easily integrate L<GitHub|https://github.com> in the C<dzil> workflow.
 
 The following is the list of the plugins shipped in this distribution:
 
@@ -47,6 +47,11 @@ The following is the list of the plugins shipped in this distribution:
 =item * L<Dist::Zilla::Plugin::GitHub::Meta> Add GitHub repo info to META.{yml,json}
 
 =back
+
+This distribution also provides an additional C<dzil> command (L<dzil
+gh|Dist::Zilla::App::Command::gh>) and a L<plugin
+bundle|Dist::Zilla::PluginBundle::GitHub>.
+
 =cut
 
 sub _get_credentials {
@@ -129,12 +134,6 @@ sub _check_response {
 	}
 }
 
-=head1 ACKNOWLEDGMENTS
-
-Both the GitHub::Create and the GitHub::Update modules used to be standalone
-modules (named respectively L<Dist::Zilla::Plugin::GithubCreate> and
-L<Dist::Zilla::Plugin::GithubUpdate>) that are now deprecated.
-
 =head1 AUTHOR
 
 Alessandro Ghedini <alexbio@cpan.org>
